die "NOTICE: YAML::Marshall has been moved to YAML::Old::Marshall.
Please see https://github.com/ingydotnet/yaml-old-pm/blob/master/doc/yaml-old-transition.md#yaml-to-yamlold-transition
 ";

=pod

=head1 NAME

YAML::Marshall - Deprecated

=head1 DESCRIPTION

The original L<YAML> distribution has been replaced by L<YAML-Old>.

C<YAML::Marshall> has been moved to L<YAML::Old::Marshall>.

Please see L<https://github.com/ingydotnet/yaml-old-pm/blob/master/doc/yaml-old-transition.md#yaml-to-yamlold-transition>

=cut
